/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* * ACCOUNT SYMBOL ICON                                                                                             * */
/* *                                                                                                                 * */
/* * This image is designed for 1:1 aspect ratio.                                                                    * */
/* *                                                                                                                 * */
/* * The variable [CAMERAZ] should be adjusted so the image is 570 pixels high when rendered at 800 x 800 pixels.    * */
/* * The variable [STROKEWIDTH] will be adjusted automatically to maintain consistent stroke widths for different    * */
/* * icons at different camera distances.                                                                            * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

//+w128 +h128 +ua
//-f +w800 +h800

#version 3.7;

global_settings {assumed_gamma 2.2}

#local CameraZ = 5.145;

camera {
   orthographic
   location <0, 0, -CameraZ>
   direction <0, 0, 1>
   scale <1, 4/3, 1>
   look_at <0, 0, 0>
} //camera

#include "colors.inc"

#background {<135, 130, 102> / 255}

#local SymbolColor_Outer = texture {pigment {color White} finish {emission 1}}
#local SymbolColor_Inner = texture {pigment {color <102 * .91, 98 * .91, 76 * .92> / 255} finish {emission 1}}

#local StrokeWidth = .2;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * MACROS                                                                                                          * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#macro Center_XY (Thing)

   #local Thing = object {Thing translate (-min_extent (Thing).x) * x}
   #local Thing = object {Thing translate (-max_extent (Thing).x / 2) * x}
   #local Thing = object {Thing translate (-max_extent (Thing).y) * y}
   #local Thing = object {Thing translate (-min_extent (Thing).y / 2) * y}

#end //#macro Center_XY

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * SYMBOLS                                                                                                         * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#local StrokeWidth = StrokeWidth * CameraZ / 4;

#local SW2 = StrokeWidth / 2;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

//Object variables:

#local HeadRadius = 1.15;

#local ShoulderRadius = 2.65;
#local ShoulderCutoffAngle = 7;
#local ShoulderHeight = .25;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#local Head = object {
   union {
      cylinder {<0, 0, -.1> <0, 0, 0>, HeadRadius texture {SymbolColor_Outer}}
      cylinder {<0, 0, -.2> <0, 0, .1>, HeadRadius - StrokeWidth texture {SymbolColor_Inner}}
   } //union
} //object

#local ShoulderCutoffY = ShoulderRadius * sin (radians (ShoulderCutoffAngle));

#local Shoulder = object {
   union {
      intersection {
         cylinder {<0, 0, -.1> <0, 0, 0>, ShoulderRadius}
         plane {y, ShoulderCutoffY inverse}
         texture {SymbolColor_Outer}
      } //intersection
      intersection {
         cylinder {<0, 0, -.2> <0, 0, .1>, ShoulderRadius - StrokeWidth}
         plane {y, ShoulderCutoffY + StrokeWidth inverse}
         texture {SymbolColor_Inner}
      } //intersection
   } //union
   translate (-HeadRadius - ShoulderRadius - ShoulderHeight) * y
} //object

#local Account = object {
   union {
      object {Head}
      object {Shoulder}
   } //union
} //object

Center_XY (Account)

object {Account}
